/*
 * file CqUserInfo.java
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.cq.CqUserInfo
 *
 * (C) Copyright IBM Corporation 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp.cq;

import javax.wvcm.ResourceList;
import javax.wvcm.WvcmException;

import com.ibm.rational.wvcm.stp.cq.CqUser.AuthenticationMode;

/**
 * Read-only information about the currently logged-in user of a user database
 */
public interface CqUserInfo
{
    /**
     * @return An AuthenticationMode enumerator indicating what method is used
     *         to authenticate this user. Will never be <b>null</b>.
     */
    AuthenticationMode getAuthenticationMode() throws WvcmException;

    /**
     * @return A String containing an encrypted copy of the user password or
     *         LDAP name. Will never be <b>null</b>.
     */
    String getAuthenticator() throws WvcmException;

    /**
     * @return A String containing the email field of this user's profile. Will
     *         never be <b>null</b>.
     */
    String getEmail() throws WvcmException;

    /**
     * @return A String containing the full name field of this user's profile.
     *         Will never be <b>null</b>.
     */
    String getFullName() throws WvcmException;

    /**
     * @return A String[] containing the name for each group this user belongs
     *         to. Will never be <b>null</b>.
     */
    String[] getGroupNames() throws WvcmException;

    /**
     * @return A String containing the login name field of the user's profile.
     *         Will never be <b>null</b>.
     */
    String getLoginName() throws WvcmException;

    /**
     * @return A String containing the content of the miscellaneous information
     *         field of this user's profile. Will never be <b>null</b>.
     */
    String getMiscellaneousInformation() throws WvcmException;

    /**
     * @return A String containing the phone field of this user's profile. Will
     *         never be <b>null</b>.
     */
    String getPhone() throws WvcmException;
}
